"""AI-SDLC: Markdown-driven SDLC with AI agent chaining."""

__version__ = "0.6.1"
__author__ = "Parker Rex"
__email__ = "me@parkerrex.com"
__description__ = "Markdown-driven SDLC with AI agent chaining."
